@@ -1,2 +1,2 @@
 from . import csvload
-import csv
\ No newline at end of file
+import csv, pandas
\ No newline at end of file
