@@ -1,7 +1,11 @@
-import csv
+import csv, pandas
 
 def load_csv(path):
     with open(path,'rt')as f:
         data = csv.reader(f)
         for row in data:
-            print(row)
\ No newline at end of file
+            print(row)
+
+def load_pandas(path):
+    result = pandas.read_csv(path)
+    print(result)
\ No newline at end of file
